==> inpost-0.1.4-py3-none-any.whl: inpost/static/__init__.py <==
from .endpoints import (
    accept_friendship,
    blik_status,
    collect,
    compartment_open,
    compartment_status,
    confirm_sent,
    confirm_sms_code,
    create,
    create_blik,
    friendship,
    login,
    logout,
    multi,
    open_sent,
    parcel,
    parcel_notifications,
    parcel_points,
    parcel_prices,
    parcels,
    refresh_token,
    reopen_sent,
    returns,
    send_sms_code,
    sent,
    shared,
    status_sent,
    terminate_collect_session,
    tickets,
    validate_friendship,
    validate_sent,
)
from .exceptions import (
    MissingParamsError,
    NoParcelError,
    NotAuthenticatedError,
    NotFoundError,
    ParcelTypeError,
    PhoneNumberError,
    ReAuthenticationError,
    RefreshTokenError,
    SingleParamError,
    SmsCodeError,
    UnauthorizedError,
    UnidentifiedAPIError,
    UnidentifiedError,
    UnidentifiedParcelError,
    UserLocationError,
)
from .friends import Friend
from .headers import appjson
from .notifications import Notification
from .parcels import (
    CompartmentLocation,
    CompartmentProperties,
    EventLog,
    MultiCompartment,
    Operations,
    Parcel,
    PickupPoint,
    Point,
    QRCode,
    Receiver,
    ReturnParcel,
    Sender,
    SentParcel,
    SharedTo,
)
from .statuses import (
    CompartmentActualStatus,
    CompartmentExpectedStatus,
    DeliveryType,
    ParcelAdditionalInsurance,
    ParcelCarrierSize,
    ParcelDeliveryType,
    ParcelLockerSize,
    ParcelOwnership,
    ParcelPointOperations,
    ParcelServiceName,
    ParcelShipmentType,
    ParcelStatus,
    ParcelType,
    PaymentStatus,
    PaymentType,
    PointType,
    ReturnsStatus,
)

__all__ = [
    "accept_friendship",
    "blik_status",
    "collect",
    "compartment_open",
    "compartment_status",
    "confirm_sent",
    "confirm_sms_code",
    "create",
    "create_blik",
    "friendship",
    "login",
    "logout",
    "multi",
    "open_sent",
    "parcel",
    "parcel_notifications",
    "parcel_points",
    "parcel_prices",
    "parcels",
    "refresh_token",
    "reopen_sent",
    "returns",
    "send_sms_code",
    "sent",
    "shared",
    "status_sent",
    "terminate_collect_session",
    "tickets",
    "validate_friendship",
    "validate_sent",
    "MissingParamsError",
    "NoParcelError",
    "NotAuthenticatedError",
    "NotFoundError",
    "ParcelTypeError",
    "PhoneNumberError",
    "ReAuthenticationError",
    "RefreshTokenError",
    "SingleParamError",
    "SmsCodeError",
    "UnauthorizedError",
    "UnidentifiedAPIError",
    "UnidentifiedError",
    "UnidentifiedParcelError",
    "UserLocationError",
    "Friend",
    "appjson",
    "Notification",
    "CompartmentLocation",
    "CompartmentProperties",
    "EventLog",
    "MultiCompartment",
    "Parcel",
    "PickupPoint",
    "Point",
    "QRCode",
    "Receiver",
    "ReturnParcel",
    "Sender",
    "SentParcel",
    "SharedTo",
    "CompartmentActualStatus",
    "CompartmentExpectedStatus",
    "DeliveryType",
    "ParcelAdditionalInsurance",
    "ParcelCarrierSize",
    "ParcelDeliveryType",
    "ParcelLockerSize",
    "ParcelOwnership",
    "ParcelPointOperations",
    "ParcelServiceName",
    "ParcelShipmentType",
    "ParcelStatus",
    "ParcelType",
    "PaymentType",
    "PointType",
    "ReturnsStatus",
]

==> inpost-0.2.0a2-py3-none-any.whl: inpost/static/__init__.py <==
from .endpoints import (
    accept_friendship_url,
    blik_status_url,
    collect_url,
    compartment_open_url,
    compartment_reopen_url,
    compartment_status_url,
    confirm_sent_url,
    confirm_sms_code_url,
    create_blik_url,
    create_url,
    friendship_url,
    login_url,
    logout_url,
    multi_url,
    open_sent_url,
    parcel_notifications_url,
    parcel_points_url,
    parcel_prices_url,
    refresh_token_url,
    reopen_sent_url,
    returns_url,
    send_sms_code_url,
    sent_url,
    shared_url,
    status_sent_url,
    terminate_collect_session_url,
    tickets_url,
    tracked_url,
    validate_friendship_url,
    validate_sent_url,
)
from .exceptions import (
    MissingParamsError,
    NoParcelError,
    NotAuthenticatedError,
    NotFoundError,
    ParcelTypeError,
    PhoneNumberError,
    ReAuthenticationError,
    RefreshTokenError,
    SingleParamError,
    SmsCodeError,
    UnauthorizedError,
    UnidentifiedAPIError,
    UnidentifiedError,
    UnidentifiedParcelError,
    UserLocationError,
)
from .friends import Friend
from .headers import appjson
from .notifications import Notification
from .parcels import (
    CompartmentLocation,
    CompartmentProperties,
    EventLog,
    MultiCompartment,
    Operations,
    Parcel,
    PickupPoint,
    Point,
    QRCode,
    Receiver,
    ReturnParcel,
    Sender,
    SentParcel,
    SharedTo,
)
from .statuses import (
    CompartmentActualStatus,
    CompartmentExpectedStatus,
    DeliveryType,
    ParcelAdditionalInsurance,
    ParcelCarrierSize,
    ParcelDeliveryType,
    ParcelLockerSize,
    ParcelOwnership,
    ParcelPointOperations,
    ParcelServiceName,
    ParcelShipmentType,
    ParcelStatus,
    ParcelType,
    PaymentStatus,
    PaymentType,
    PointType,
    ReturnsStatus,
)

__all__ = [
    "accept_friendship_url",
    "blik_status_url",
    "collect_url",
    "compartment_open_url",
    "compartment_reopen_url",
    "compartment_status_url",
    "confirm_sent_url",
    "confirm_sms_code_url",
    "create_url",
    "create_blik_url",
    "friendship_url",
    "login_url",
    "logout_url",
    "multi_url",
    "open_sent_url",
    "tracked_url",
    "parcel_notifications_url",
    "parcel_points_url",
    "parcel_prices_url",
    "parcels",
    "refresh_token_url",
    "reopen_sent_url",
    "returns_url",
    "send_sms_code_url",
    "sent_url",
    "shared_url",
    "status_sent_url",
    "terminate_collect_session_url",
    "tickets_url",
    "validate_friendship_url",
    "validate_sent_url",
    "MissingParamsError",
    "NoParcelError",
    "NotAuthenticatedError",
    "NotFoundError",
    "ParcelTypeError",
    "PhoneNumberError",
    "ReAuthenticationError",
    "RefreshTokenError",
    "SingleParamError",
    "SmsCodeError",
    "UnauthorizedError",
    "UnidentifiedAPIError",
    "UnidentifiedError",
    "UnidentifiedParcelError",
    "UserLocationError",
    "Friend",
    "appjson",
    "Notification",
    "CompartmentLocation",
    "CompartmentProperties",
    "EventLog",
    "MultiCompartment",
    "Parcel",
    "PickupPoint",
    "Point",
    "QRCode",
    "Receiver",
    "ReturnParcel",
    "Sender",
    "SentParcel",
    "SharedTo",
    "CompartmentActualStatus",
    "CompartmentExpectedStatus",
    "DeliveryType",
    "ParcelAdditionalInsurance",
    "ParcelCarrierSize",
    "ParcelDeliveryType",
    "ParcelLockerSize",
    "ParcelOwnership",
    "ParcelPointOperations",
    "ParcelServiceName",
    "ParcelShipmentType",
    "ParcelStatus",
    "ParcelType",
    "PaymentType",
    "PointType",
    "ReturnsStatus",
]
